@@ -7,6 +7,6 @@ from .compound import Compound, FormulaCompound
 from .compound import CarbonDioxide, Water
 from .reaction import Reaction, CombustionTrain
 
-from .electrochemistry.molar import molarity
+from .solutions.molar import molarity
 
 from .utils.constants import *
\ No newline at end of file
